use actix_session::Session;
use actix_web_httpauth::extractors::basic::BasicAuth;

pub trait AuthValidator {
        fn check_user(&self, name : &String, pwd : &String) -> bool;

        fn check_basic(&self, basic : &BasicAuth) -> Option<User> {
                match basic.password() {
                        Option::Some(pwd) => {
                                let username = basic.user_id().to_string();
                                if self.check_user(&username, &pwd.to_string()) {
                                        Some(User(username))
                                } else {
                                        None
                                }
                }
                        Option::None => {None}
                }
                //basic.password().and_then(|pwd| self.check_user(&basic.user_id().to_string(), &pwd.to_string()))
        }

        fn check_session(&self, session : &Session) -> Option<User> {
                let result = session.get::<String>("user");
                match result {
                        Ok(username) => {username.map(|u| User(u))}
                        Err(e) => {
                                println!("{}", e);
                                None
                        }
                }
        }
}

pub struct TestValidator;

impl AuthValidator for TestValidator {
        fn check_user(&self, name: &String, pwd: &String) -> bool {
                pwd.eq(&(name.clone() + "pwd"))
        }
}

pub struct User(String);

impl User {
        pub fn get_name(&self) -> String {
                self.0.clone()
        }
}
